@@ -18,7 +18,7 @@ use XML::Feed;
 
 use Perlanet::Types;
 
-our $VERSION = '2.2.1';
+our $VERSION = '3.0.0';
 
 with 'MooseX::Traits';
 
@@ -203,16 +203,16 @@ sub fetch_feeds {
 
   my @valid_feeds;
   for my $feed (@$feeds) {
-    my $response = $self->fetch_page($feed->url);
+    my $response = $self->fetch_page($feed->feed);
 
     if ($response->is_error) {
-      carp 'Error retrieving ' . $feed->url;
+      carp 'Error retrieving ' . $feed->feed;
       carp $response->http_response->status_line;
       next;
     }
 
     unless (length $response->content) {
-      carp 'No data returned from ' . $feed->url;
+      carp 'No data returned from ' . $feed->feed;
       next;
     }
 
@@ -226,7 +226,7 @@ sub fetch_feeds {
       push @valid_feeds, $feed;
     }
     catch {
-      carp 'Errors parsing ' . $feed->url;
+      carp 'Errors parsing ' . $feed->feed;
       carp $_ if defined $_;
     };
   }
@@ -362,11 +362,11 @@ sub build_feed {
   my $self = shift;
   my ($entries) = @_;
 
-  my $self_url = $self->self_link;
-
-  my $f = Perlanet::Feed->new( modified    => DateTime->now );
+  my $f = Perlanet::Feed->new(
+    modified => DateTime->now,
+    feed     => $self->config->{url},
+  );
   $f->title($self->title)             if defined $self->title;
-  $f->url($self->url)                 if defined $self->url;
   $f->description($self->description) if defined $self->description;
   if (defined $self->{'author'} ) {
     $f->author($self->author->{name})   if defined $self->author->{name};
