@@ -1,5 +1,6 @@
 package Perlanet::Trait::Tidy;
 
+use 5.10.0;
 use strict;
 use warnings;
 
@@ -23,7 +24,7 @@ Perlanet::Trait::Tidy - run posts through HTML::Tidy
 
 =head1 DESCRIPTION
 
-Before a post is added to the aggregated feed, it will be ran through
+Before a post is added to the aggregated feed, it will be run through
 HTML::Tidy.
 
 =head2 Configuring
@@ -71,6 +72,8 @@ around 'clean_html' => sub {
   my $self = shift;
   my ($html) = @_;
 
+  warn __PACKAGE__, '::clean_html' if $ENV{PERLANET_DEBUG};
+
   $html = $self->$orig($html);
 
   my $clean = $self->tidy->clean(utf8::is_utf8($html)
